pub struct Cnx {
pub src: String,
pub dst: String,
pub msg: String,
pub missions: Option<Vec<String>>,
pub src_channel: Option<String>,
pub dst_channel: Option<String>,
}Expand description
This represents a connection between 2 tasks (nodes) in the configuration graph.
Fields
src: StringSource node id.
dst: StringDestination node id.
msg: StringMessage type exchanged between src and dst.
missions: Option<Vec<String>>Restrict this connection for this list of missions.
src_channel: Option<String>Optional channel id when the source endpoint is a bridge.
dst_channel: Option<String>Optional channel id when the destination endpoint is a bridge.