Function begin_observed_encode
pub fn begin_observed_encode()Expand description
Starts observed byte counting for the current encode pass.
pub fn begin_observed_encode()Starts observed byte counting for the current encode pass.