pub(crate) fn build_node_table(
node: &RenderNode,
node_weight: &Node,
header_fill: &str,
) -> (TableNode, PortLookup)Expand description
Build the record table for a node and capture port ids for routing.
pub(crate) fn build_node_table(
node: &RenderNode,
node_weight: &Node,
header_fill: &str,
) -> (TableNode, PortLookup)Build the record table for a node and capture port ids for routing.