pub(crate) fn draw_node_table(
svg: &mut SvgWriter,
node: &NodeRender,
element: &Element,
offset: Point,
)Expand description
Draw table cells manually since the layout engine only positions shapes.
pub(crate) fn draw_node_table(
svg: &mut SvgWriter,
node: &NodeRender,
element: &Element,
offset: Point,
)Draw table cells manually since the layout engine only positions shapes.