Function observed_encode_bytes
pub fn observed_encode_bytes() -> usizeExpand description
Returns the number of bytes written so far in the current observed encode pass.
pub fn observed_encode_bytes() -> usizeReturns the number of bytes written so far in the current observed encode pass.