pub(crate) fn render_sections_to_svg(
sections: &[SectionLayout],
interconnects: &[InterconnectRender],
) -> CuResult<String>Expand description
Render each section and merge them into a single SVG canvas.
pub(crate) fn render_sections_to_svg(
sections: &[SectionLayout],
interconnects: &[InterconnectRender],
) -> CuResult<String>Render each section and merge them into a single SVG canvas.