pub(crate) fn visit_table(
node: &TableNode,
dir: Orientation,
loc: Point,
size: Point,
visitor: &mut dyn TableVisitor,
)Expand description
Walk table cells to compute positions and collect port anchors.
pub(crate) fn visit_table(
node: &TableNode,
dir: Orientation,
loc: Point,
size: Point,
visitor: &mut dyn TableVisitor,
)Walk table cells to compute positions and collect port anchors.