Struct CuCompactString
pub struct CuCompactString(pub CompactString);Tuple Fields
0: CompactStringTrait Implementations
impl<'de, Context> BorrowDecode<'de, Context> for CuCompactString
impl<'de, Context> BorrowDecode<'de, Context> for CuCompactString
fn borrow_decode<D>(decoder: &mut D) -> Result<CuCompactString, DecodeError>where
D: BorrowDecoder<'de>,
fn borrow_decode<D>(decoder: &mut D) -> Result<CuCompactString, DecodeError>where
D: BorrowDecoder<'de>,
Attempt to decode this type with the given BorrowDecode.
impl Clone for CuCompactString
impl Clone for CuCompactString
fn clone(&self) -> CuCompactString
fn clone(&self) -> CuCompactString
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for CuCompactString
impl Debug for CuCompactString
impl<Context> Decode<Context> for CuCompactString
impl<Context> Decode<Context> for CuCompactString
fn decode<D>(decoder: &mut D) -> Result<CuCompactString, DecodeError>where
D: Decoder,
fn decode<D>(decoder: &mut D) -> Result<CuCompactString, DecodeError>where
D: Decoder,
Attempt to decode this type with the given Decode.
impl Default for CuCompactString
impl Default for CuCompactString
fn default() -> CuCompactString
fn default() -> CuCompactString
Returns the “default value” for a type. Read more
impl<'de> Deserialize<'de> for CuCompactString
impl<'de> Deserialize<'de> for CuCompactString
fn deserialize<__D>(
__deserializer: __D,
) -> Result<CuCompactString, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<CuCompactString, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Encode for CuCompactString
impl Encode for CuCompactString
impl PartialEq for CuCompactString
impl PartialEq for CuCompactString
impl Serialize for CuCompactString
impl Serialize for CuCompactString
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for CuCompactString
impl StructuralPartialEq for CuCompactString