pub(crate) struct NullBackend;Trait Implementations
Sourceimpl RenderBackend for NullBackend
impl RenderBackend for NullBackend
Sourcefn draw_rect(
&mut self,
_xy: Point,
_size: Point,
_look: &StyleAttr,
_properties: Option<String>,
_clip: Option<ClipHandle>,
)
fn draw_rect( &mut self, _xy: Point, _size: Point, _look: &StyleAttr, _properties: Option<String>, _clip: Option<ClipHandle>, )
Draw a rectangle. The top-left point of the rectangle is \p xy. The shape
style (color, edge-width) are passed in \p look. The parameter \p clip
is an optional clip region (see: create_clip).
Sourcefn draw_line(
&mut self,
_start: Point,
_stop: Point,
_look: &StyleAttr,
_properties: Option<String>,
)
fn draw_line( &mut self, _start: Point, _stop: Point, _look: &StyleAttr, _properties: Option<String>, )
Draw a line between \p start and \p stop.
Sourcefn draw_circle(
&mut self,
_xy: Point,
_size: Point,
_look: &StyleAttr,
_properties: Option<String>,
)
fn draw_circle( &mut self, _xy: Point, _size: Point, _look: &StyleAttr, _properties: Option<String>, )
Draw an ellipse with the center \p xy, and size \p size.
Sourcefn draw_arrow(
&mut self,
_path: &[(Point, Point)],
_dashed: bool,
_head: (bool, bool),
_look: &StyleAttr,
_properties: Option<String>,
_text: &str,
)
fn draw_arrow( &mut self, _path: &[(Point, Point)], _dashed: bool, _head: (bool, bool), _look: &StyleAttr, _properties: Option<String>, _text: &str, )
Draw an arrow, with a label, with the style parameters in \p look.
Sourcefn create_clip(&mut self, _xy: Point, _size: Point, _rounded_px: usize) -> usize
fn create_clip(&mut self, _xy: Point, _size: Point, _rounded_px: usize) -> usize
Generate a clip region that shapes can use to create complex shapes.