pub(crate) fn render_sections_to_svg(sections: &[SectionLayout]) -> StringExpand description
Render each section and merge them into a single SVG canvas.
pub(crate) fn render_sections_to_svg(sections: &[SectionLayout]) -> StringRender each section and merge them into a single SVG canvas.